@@ -449,7 +449,6 @@ class IQ_Option:
 
         else:
             logging.error("ERROR doesn't have this mode")
-            exit(1)
 
     # ________________________________________________________________________
     # _______________________        CANDLE      _____________________________
@@ -467,7 +466,7 @@ class IQ_Option:
                     break
             except:
                 logging.error('**error** get_candles need reconnect')
-                self.connect()
+                raise ConnectionError
 
         return self.api.candles.candles_data
 
